==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_results/mp0220_002/ChildTransaction.java <==

package net.datastream.schemas.mp_results.mp0220_002;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "workorderid"
})
@XmlRootElement(name = "ChildTransaction")
public class ChildTransaction {

    @XmlElement(name = "TRANSACTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;

    /**
     * Obtient la valeur de la propriété transactionid.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Définit la valeur de la propriété transactionid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_results/mp0220_002/ChildTransaction.java <==

package net.datastream.schemas.mp_results.mp0220_002;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TRANSACTIONID_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "workorderid"
})
@XmlRootElement(name = "ChildTransaction")
public class ChildTransaction {

    @XmlElement(name = "TRANSACTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;

    /**
     * Gets the value of the transactionid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Sets the value of the transactionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

}
